@@ -109,13 +109,11 @@ class TestITListener(object):
                                      1 < len(items) and item.originalname == \
                                      items[item_id + 1].originalname else 0
 
-                if (
-                        configurations_array
-                        and item.test_external_id in configurations_array
-                ):
-                    item.test_configuration_id = configurations_array[
-                        item.test_external_id]
-                    new_items.append(item)
+                if configurations_array:
+                    if item.test_external_id in configurations_array:
+                        item.test_configuration_id = configurations_array[
+                            item.test_external_id]
+                        new_items.append(item)
                 else:
                     item_id = session.items.index(item)
                     session.items[item_id].test_configuration_id = self.configuration_id
